import * as Utils from "../utils";
/**
 * this.apiClient.request("GET", url, requestBody, headers, queryParameters);
 */
export const create = (factory, params, methodType) => {
    const { convertedParams } = params;
    const apiClientVariableIdentifier = {
        class: "this.apiClient.request",
        function: "apiClient.request",
    };
    const expression = Utils.generateVariableIdentifier(factory, apiClientVariableIdentifier[methodType]);
    const requestArgs = factory.ObjectLiteralExpression.create({
        properties: [
            factory.PropertyAssignment.create({
                name: "httpMethod",
                initializer: factory.StringLiteral.create({ text: params.operationParams.httpMethod.toUpperCase() }),
            }),
            factory.PropertyAssignment.create({
                name: "url",
                initializer: factory.Identifier.create({ name: "url" }),
            }),
            factory.PropertyAssignment.create({
                name: "headers",
                initializer: factory.Identifier.create({ name: "headers" }),
            }),
            factory.PropertyAssignment.create({
                name: "requestBody",
                initializer: convertedParams.hasRequestBody
                    ? Utils.generateVariableIdentifier(factory, "params.requestBody")
                    : factory.Identifier.create({ name: "undefined" }),
            }),
            factory.PropertyAssignment.create({
                name: "queryParameters",
                initializer: convertedParams.hasQueryParameters
                    ? factory.Identifier.create({ name: "queryParameters" })
                    : factory.Identifier.create({ name: "undefined" }),
            }),
        ],
        multiLine: true,
    });
    const argumentsArray = [requestArgs, factory.Identifier.create({ name: "option" })];
    return factory.CallExpression.create({
        expression: expression,
        typeArguments: [],
        argumentsArray: argumentsArray,
    });
};
//# sourceMappingURL=CallRequest.js.map